package com.vendor.burn.model.cmdline.adapter;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.log.Log;
import com.vendor.burn.model.PartitionInfo;
import com.vendor.burn.model.PartitionItem;
import com.vendor.burn.model.cmdline.EEmmcImg;
import com.vendor.burn.model.cmdline.adapter.CommonAdapter;
import com.vendor.burn.model.devices.unknown.UnknownDevice;
import com.vendor.burn.views.FastbootView;
import java.io.File;
import java.util.List;
import org.dom4j.DocumentException;
import org.eclipse.osgi.util.NLS;

public class EmmcImg extends CommonAdapter {
  private UnknownDevice device;
  
  private String chipName;
  
  private String xmlPath;
  
  private String outputPath;
  
  private List<PartitionItem> partitionList;
  
  public boolean parseAllParameter(String[] args, int paramSize) {
    if (!parseChipName(args, paramSize)) {
      printEmmcImgEg();
      return false;
    } 
    if (!parseOutputFile(args, paramSize)) {
      printEmmcImgEg();
      return false;
    } 
    if (!parseXmlPath(args, paramSize)) {
      printEmmcImgEg();
      return false;
    } 
    return true;
  }
  
  public boolean parseChipName(String[] args, int paramSize) {
    if (args == null) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EEmmcImg.chipName.name()));
      return false;
    } 
    if (paramSize >= EEmmcImg.chipName.ordinal()) {
      String chipName = args[EEmmcImg.chipName.ordinal()];
      if (chipName == null || chipName.isEmpty()) {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_IsNull, EEmmcImg.chipName.name()));
        return false;
      } 
      String upperCaseChipName = convertChipName(chipName);
      UnknownDevice device = new UnknownDevice(upperCaseChipName);
      if (!device.isValid()) {
        Log.errorln(Messages.FastbootView_Unsupported_Device);
        return false;
      } 
      FastbootView.setCurrentChipNameType(device.getChipNameType());
      setChipName(upperCaseChipName);
      setDevice(device);
      return true;
    } 
    Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EEmmcImg.chipName.name()));
    return false;
  }
  
  public boolean parseOutputFile(String[] args, int paramSize) {
    if (args == null) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EEmmcImg.outputFile.name()));
      return false;
    } 
    if (paramSize >= EEmmcImg.outputFile.ordinal()) {
      String outputFilePath = args[EEmmcImg.outputFile.ordinal()];
      boolean result = (outputFilePath == null || outputFilePath.isEmpty());
      if (result) {
        Log.errorln(NLS.bind(Messages.CMD_PARAMETER_IsNull, EEmmcImg.outputFile.name()));
        return false;
      } 
      File file = new File(outputFilePath);
      if (file.isDirectory()) {
        Log.errorln(NLS.bind(Messages.AbstractBurner_msg_the_file_can_not_be_a_directory, file.getName()));
        return false;
      } 
      setOutputPath(outputFilePath);
    } else {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EEmmcImg.outputFile.name()));
      return false;
    } 
    return true;
  }
  
  public boolean parseXmlPath(String[] args, int paramSize) {
    if (args == null) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EEmmcImg.xmlPath.name()));
      return false;
    } 
    if (paramSize >= EEmmcImg.xmlPath.ordinal()) {
      String xmlPath = args[EEmmcImg.xmlPath.ordinal()];
      if (xmlPath == null)
        return false; 
      File file = new File(xmlPath);
      if (!file.exists() || !file.isFile()) {
        Log.errorln(NLS.bind(Messages.ERROR_CURRENT_XML_PATH_NOT_FOUND, xmlPath));
        return false;
      } 
      try {
        PartitionInfo partitionInfo = PartitionItem.load(file, true);
        List<PartitionItem> partitionList = partitionInfo.getChildren();
        if (partitionList != null && partitionList.size() > 0) {
          setXmlPath(xmlPath);
          setPartitionList(partitionList);
          return true;
        } 
        Log.errorln(NLS.bind(Messages.MESSAGE_FAILED_To_LOAD_FILE, file.getName()));
        return false;
      } catch (DocumentException e) {
        Log.errorln(NLS.bind(Messages.MESSAGE_FAILED_To_LOAD_FILE, file.getName()));
        return false;
      } 
    } 
    Log.errorln(NLS.bind(Messages.CMD_PARAMETER_NotFound, EEmmcImg.xmlPath.name()));
    return false;
  }
  
  public static void printEmmcImgEg() {
    Log.println("burntoolcli.jar --emmcimg  <chipName>      <outputFile>              <xmlPath>           ");
    Log.println("burntoolcli.jar --emmcimg  chipName   image/emmcImg.bin    image/emmc_partitions.xml  ");
  }
  
  public String getChipName() {
    return this.chipName;
  }
  
  public void setChipName(String chipName) {
    this.chipName = chipName;
  }
  
  public UnknownDevice getDevice() {
    return this.device;
  }
  
  public void setDevice(UnknownDevice device) {
    this.device = device;
  }
  
  public String getXmlPath() {
    return this.xmlPath;
  }
  
  public void setXmlPath(String xmlPath) {
    this.xmlPath = xmlPath;
  }
  
  public List<PartitionItem> getPartitionList() {
    return this.partitionList;
  }
  
  public void setPartitionList(List<PartitionItem> partitionList) {
    this.partitionList = partitionList;
  }
  
  public String getOutputPath() {
    return this.outputPath;
  }
  
  public void setOutputPath(String outputPath) {
    this.outputPath = outputPath;
  }
}
